*************************************************************************
*** Replication of: 
*** Gaibulloev, Khusrav and Todd Sandler. 2018. Terrorism and affinity of 
*** nations. Public Choice. https://doi.org/10.1007/s11127-018-0611-8 
*************************************************************************
*** reg_terr-affin.do	2018-16-09
*************************************************************************

// NOTE: outreg2 is used to make tables: it is a user-written command 
// 		that needs to be installed

clear
set more off
set matsize 1000
capture log close

log using reg-results, text replace

use data_terr-affinity.dta, replace

*** Construct affinity var-s
egen affinity2=rowmean(ms2unuk ms2unfra ms2unger ms2unus)
egen idiff=rowmean(midldiffus midldiffuk midldifffra midldiffger)
egen idiffeur=rowmean(midldiffuk midldifffra midldiffger)
egen agrun2=rowmean(magr2unus magr2unuk magr2unfra magr2unger)
gen idiffus=midldiffus

lab var idiff "Ideal Points Distance"
lab var affinity2 "Affinity"
lab var idiffeur "Ideal Points Distance EUR"
lab var idiffus "Ideal Points Distance US"
lab var agrun2 "UN vote"

*******************************************************************************
**** Descriptive Stats: Appendix Tables A1 and A2  ***********
**************************************************************
qui nbreg miter affinity2 mpolt mpolt2 mdurable mcivwar mdiscpop ///
	mlinc mlogpop meglob mpglob maidpc i.year i.ccode, vce(cluster ccode)
gen samp=e(sample)
su miter mgtter mgdter miterc mgtterc mgdterc idiff affinity2 idiffeur idiffus ///
	mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop meglob mpglob ///
	maidpc if samp==1 //Table A1
corr idiff affinity2 agrun2 idiffeur idiffus if samp==1 // Table A2


*** Table 1 ********************************************************************
nbreg miter idiff i.year i.ccode, vce(cluster ccode)
outreg2 using Table1, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(idiff affinity2) drop(i.ccode i.year) label ///
	dec(3) addtext (Country FE, Yes, Time FE, Yes) addst(N, e(N_clust)) ///
	title("Baseline regressions for political affinity and transnational terrorism")
nbreg miter affinity2 i.year i.ccode, vce(cluster ccode)
outreg2
foreach x of varlist idiff affinity2 {
	nbreg mgtter `x' i.year i.ccode, vce(cluster ccode)
	outreg2 
}


*** Table 2 ********************************************************************
nbreg miter idiff i.year i.ccode, vce(cluster ccode)
outreg2 using Table2, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(idiff affinity2 mpolt mpolt2 mdurable mcivwar mdiscpop ///
	mlinc mlogpop meglob mpglob maidpc) drop(i.ccode i.year) label ///
	dec(3) addtext (Country FE, Yes, Time FE, Yes) addst(N, e(N_clust)) ///
	title("Main regressions for political affinity and transnational terrorism")
foreach y of varlist miter mgtter {
								foreach x of varlist idiff affinity2 {
	nbreg `y' `x' mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	meglob mpglob maidpc i.year i.ccode, vce(cluster ccode)
	outreg2
}
}


*** Table 3 & appendix Table A3 ***********************************************
nbreg miterc idiff mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	meglob mpglob maidpc i.year i.ccode, vce(cluster ccode)
outreg2 using Table3, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(idiff mpolt mpolt2 mdurable mcivwar mdiscpop ///
	mlinc mlogpop meglob mpglob maidpc minterventions mcrisis3years ///
	mAlliance mtrade lme) drop(i.ccode i.year) label ///
	dec(3) addtext (Country FE, Yes, Time FE, Yes) addst(N, e(N_clust)) ///
	title("Robustness analyses for political affinity and transnational terrorism")
nbreg mgtterc idiff mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	meglob mpglob maidpc i.year i.ccode, vce(cluster ccode)
outreg2
nbreg miter idiff mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop meglob ///
	mpglob maidpc i.year i.ccode if namerica!=1 & europe!=1, vce(cluster ccode)
outreg2
nbreg mgtter idiff mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop meglob ///
	mpglob maidpc i.year i.ccode if namerica!=1 & europe!=1, vce(cluster ccode)
outreg2
nbreg miter idiff mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	mpglob maidpc minterventions mcrisis3years mAlliance mtrade lme ///
	i.year i.ccode, vce(cluster ccode)	
outreg2
nbreg mgtter idiff mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	mpglob maidpc minterventions mcrisis3years mAlliance mtrade lme ///
	i.year i.ccode, vce(cluster ccode)	
outreg2


*** Table 4 & appendix Table A4 ***********************************************
xtset ccode year
nbreg miter l.idiff mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	meglob mpglob maidpc i.year i.ccode, vce(cluster ccode)
outreg2 using Table4, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(l.idiff idiffeur idiffus mpolt mpolt2 mdurable mcivwar mdiscpop ///
	mlinc mlogpop meglob mpglob maidpc) drop(i.ccode i.year) label ///
	dec(3) addtext (Country FE, Yes, Time FE, Yes) addst(N, e(N_clust)) ///
	title("Further robustness analyses for political affinity and transnational terrorism") 
nbreg mgtter l.idiff mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	meglob mpglob maidpc i.year i.ccode, vce(cluster ccode) 
outreg2
foreach y of varlist miter mgtter {
	nbreg `y' idiffeur mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	meglob mpglob maidpc i.year i.ccode, vce(cluster ccode)
	outreg2
}
foreach y of varlist miter mgtter {
	nbreg `y' idiffus mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	meglob mpglob maidpc i.year i.ccode, vce(cluster ccode)
	outreg2
}


*** Table 5 & appendix Tables A5 & A6 *****************************************
xtset ccode year
nbreg mgdter idiff i.year i.ccode, vce(cluster ccode)		
outreg2 using Table5, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(idiff l.idiff affinity2 idiffeur idiffus mpolt mpolt2 mdurable ///
	mcivwar mdiscpop mlinc mlogpop mtrade mpglob maidpc minterventions ///
	mcrisis3years mAlliance lme) drop(i.ccode i.year) label ///
	dec(3) addtext (Country FE, Yes, Time FE, Yes) addst(N, e(N_clust)) ///
	title("Political affinity and domestic terrorism")
foreach y of varlist mgdter mgdterc {
	nbreg `y' idiff mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	mtrade mpglob maidpc i.year i.ccode, vce(cluster ccode)
	outreg2
	nbreg `y' idiff mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	mtrade mpglob maidpc i.year i.ccode if namerica!=1 & europe!=1, ///
	vce(cluster ccode)
	outreg2
	nbreg `y' idiff mpolt mpolt2 mdurable mcivwar mdiscpop minterventions ///
	mcrisis3years mAlliance mlinc mlogpop mtrade lme mpglob maidpc i.year ///
	i.ccode, vce(cluster ccode)
	outreg2
	nbreg `y' l.idiff mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	mtrade mpglob maidpc i.year i.ccode, vce(cluster ccode)
	outreg2
	nbreg `y' affinity2 mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	mtrade mpglob maidpc i.year i.ccode, vce(cluster ccode)
	outreg2
	nbreg `y' idiffeur mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	mtrade mpglob maidpc i.year i.ccode, vce(cluster ccode)
	outreg2
	nbreg `y' idiffus mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	mtrade mpglob maidpc i.year i.ccode, vce(cluster ccode)
	outreg2
}


*** Table 6 & appendix Table A7 ***********************************************
gen iternonus=miter-miusvic
nbreg iternonus idiffus mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	meglob mpglob maidpc i.year i.ccode, vce(cluster ccode)
outreg2 using Table6, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(idiffus mpolt mpolt2 mdurable mcivwar mdiscpop ///
	mlinc mlogpop meglob mpglob maidpc) drop(i.ccode i.year) label ///
	dec(3) addtext (Country FE, Yes, Time FE, Yes) addst(N, e(N_clust)) ///
	title("Political affinity with the US and ITERATE attacks against US versus non-US targets")
nbreg iternonus idiffus mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	meglob mpglob maidpc i.year i.ccode if namerica!=1 & europe!=1, ///
	vce(cluster ccode)
outreg2
nbreg miusvic idiffus mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	meglob mpglob maidpc i.year i.ccode, vce(cluster ccode)
outreg2	
nbreg miusvic idiffus mpolt mpolt2 mdurable mcivwar mdiscpop mlinc mlogpop ///
	meglob mpglob maidpc i.year i.ccode if namerica!=1 & europe!=1, ///
	vce(cluster ccode)
outreg2

	
log c
